@@ -3,7 +3,7 @@ from pathlib import Path
 from datetime import datetime
 
 class logger:
-    def __init__(self, log_filepath=None, max_lines=100_000, level='info', name=None, log_to_file=True):
+    def __init__(self, log_filepath=None, max_lines=5_000_000, level='info', name=None, log_to_file=True):
         filename = Path(sys.argv[0]).stem
         self.filename = filename
         if not log_filepath:
@@ -41,7 +41,7 @@ class logger:
         self.current_time('Starting', name)
         self.log()
 
-    def log(self, *items, level='info', beautify=True):
+    def print(self, *items, level='info', beautify=True):
         message = prettify(items, beautify=beautify)
 
         if not message:
@@ -77,6 +77,9 @@ class logger:
                 self.logger.addHandler(log_file)
                 self.log_file = log_file
     
+    def log(self, *items, level='info', beautify=True):
+        self.print(*items, level=level, beautify=beautify)
+    
     def error(self, *items):
         self.log(*items, level='error')
     
